==> cook.1.7.tar.gz: cook.1.7/c_incl/sniff.h <==
/*
 *	cook - file construction tool
 *	Copyright (C) 1991, 1992, 1993, 1994 Peter Miller.
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * MANIFEST: interface definition for c_incl/sniff.c
 */

#ifndef SNIFF_H
#define SNIFF_H

#include <stdio.h>
#include <main.h>

enum
{
	absent_ignore,
	absent_mention,
	absent_error
};

typedef struct option_ty option_ty;
struct option_ty
{
	int	o_verbose;
	int	o_absent_local;
	int	o_absent_system;
	int	o_absent_program;
};
extern option_ty option;

struct wlist;

typedef struct sniff_ty sniff_ty;
struct sniff_ty
{
	int (*scan)_((FILE *, struct wlist *, struct wlist *));
	void (*prepare)_((void));
};

extern	sniff_ty	lang_c;
extern	sniff_ty	lang_roff;

extern char *prefix;
extern char *suffix;

void sniff _((char *));
void sniff_include _((char *));
long sniff_include_count _((void));
void sniff_prepare _((void));
void sniff_language _((sniff_ty *));

#endif /* SNIFF_H */

==> cook_2.5.orig.tar.gz: cook-2.5.orig/c_incl/sniff.h <==
/*
 *	cook - file construction tool
 *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for c_incl/sniff.c
 */

#ifndef C_INCL_SNIFF_H
#define C_INCL_SNIFF_H

#include <stdio.h>
#include <main.h>

enum
{
	absent_ignore,
	absent_mention,
	absent_error
};

typedef struct option_ty option_ty;
struct option_ty
{
	int	o_verbose;
	int	o_absent_local;
	int	o_absent_system;
	int	o_absent_program;
	int	no_src_rel_inc;
	int	absolute;
	int	recursive;
	int	escape_newline;
	char	*output;
};
extern option_ty option;

struct string_list_ty;

typedef struct sniff_ty sniff_ty;
struct sniff_ty
{
	int (*scan)_((FILE *, struct string_list_ty *, struct string_list_ty *));
	void (*prepare)_((void));
};

void sniff _((char *));
void sniff_include _((char *));
void sniff_include_cut _((void));
long sniff_include_count _((void));
void sniff_prepare _((void));
void sniff_language _((sniff_ty *));

void sniff_remove_leading_path _((char *));
void sniff_substitute_leading_path _((char *, char *));

int absolute_filename_test _((char *));

void sniff_prefix_set _((char *));
void sniff_suffix_set _((char *));

#endif /* C_INCL_SNIFF_H */
